#! /bin/sh
usage(){
        echo "Usage : "
        echo "  rf_tx.sh <channel> <phyrate> <preamble> <packet length LSB> <packet length MSB> <interframe space LSB> <interframe space MSB>" 
} 

run_pre_test(){
echo "Remove current FW"
echo "rmmod ga_linuxdrv"

dhcpcd -k
killall wpa_supplicant
ifconfig eth0 down
sleep 1
rmmod ga_linuxdrv

echo "Insert MMC FW"
echo "insmod /usr/local/drivers/ga_linuxdrv.o giFWType=1 pu8MACAddr=AABBCCDDEEFF"
insmod /usr/local/drivers/ga_linuxdrv.o giFWType=1 pu8MACAddr=AABBCCDDEEFF
}

run_test(){
echo "Start MMC FW"
echo "/user_data/prod/bin/pctitool "$interface $start_cmd" 255"
/user_data/prod/bin/pctitool $interface $start_cmd 255

echo "Start Test"
echo "/user_data/prod/bin/pctitool "$interface $test_cmd" 255 "$channel $antenna $phyrate $preamble $packet_length_LSB $packet_length_MSB $interframe_space_LSB $interframe_space_MSB $packets_number
/user_data/prod/bin/pctitool $interface $test_cmd 255 $channel $antenna $phyrate $preamble $packet_length_LSB $packet_length_MSB $interframe_space_LSB $interframe_space_MSB $packets_number
}

#  Set default parameters
set_default_parameters(){
  channel='10'
  phyrate='0'
  preamble='1'
  packet_length_LSB='220'
  packet_length_MSB='5'
  interframe_space_LSB='6'  
  interframe_space_MSB='0' 
}

# Calculate value and display physical rate
get_phyrate_real_value(){
case $phyrate in
   '0') real_phyrate='1';;
   '1') real_phyrate='2';;
   '2') real_phyrate='5.5';;
   '3') real_phyrate='11';;
   '11') real_phyrate='6';;
   '15') real_phyrate='9';;
   '10') real_phyrate='12';;
   '14') real_phyrate='18';;
   '9') real_phyrate='24';;
   '13') real_phyrate='36';;
   '8') real_phyrate='48';;
   '12') real_phyrate='54';;
   *) real_phyrate='*****XXXXXXX*****';;
esac
}

# Calculate value to display for packet length
get_packet_length_real_value(){
real_packet_length=$packet_length_MSB
let $[ real_packet_length *= 256 ]
let $[ real_packet_length += $packet_length_LSB ]
}

# Calculate value to display for interframe space
get_interframe_space_real_value(){
real_interframe_space=$interframe_space_MSB
let $[ real_interframe_space *= 256 ]
let $[ real_interframe_space += $interframe_space_LSB ]
}

display_parameters(){
# Display interface
  echo "Interface="$interface

# Display channel
  echo "Channel="$channel 

# Calculate value to display for physical rate
  get_phyrate_real_value
  echo "Physical rate="$real_phyrate"mbps"

# Display preamble
case $preamble in
   '0') echo "Preamble short";;
   '1') echo "Preamble long";;
   *) echo "Preamble "$preamble" : unknown value";;
esac

# Calculate value to display for packet length
get_packet_length_real_value
echo "Packet length= "$real_packet_length"bytes"

# Calculate value to display for interframe space
get_interframe_space_real_value
echo "Interframe space= "$real_interframe_space"us" 
 
}

# ************** Start script ************
if [ $# -ne 7 ]; then
  if [ $# -ne 0 ]; then
      # At least one parameter is missing
      usage
      exit 1
  else
      # No parameters provided -> use default! 
      echo "Use default values!!!"
      set_default_parameters
  fi
else
  # Get parameters for command line
  channel=$1
  phyrate=$2
  preamble=$3
  packet_length_LSB=$4
  packet_length_MSB=$5
  interframe_space_LSB=$6  
  interframe_space_MSB=$7 
fi

# prepare driver for test
run_pre_test

# Get current interface
eth_num=`tail -n1 /proc/net/wireless | awk '{print $1}'| cut -b4`
interface='eth'$eth_num

# Set default value for antenna
  antenna='0'

# Set infinite loop for test
  packets_number='0 0 0 0'

# Set commands
  start_cmd='1'
  test_cmd='4'

display_parameters

run_test

#run_pctitool
                                    
