#!/bin/bash
#================================================
# this script is used by Hxx_ats.sh
# and by patch6.sh
# all specific treatments are tagged #+ GA  ... #- GA or #+ OBIWAN ... #- OBIWA
#================================================


#================================================
# - Mask return value
#--------------------------------
NO_TRACE()
{
   $* 2>/dev/null 1>&2
}

#########################################################
# function : becho
#
#     like echo but display in bold
#########################################################
becho() {
   echo -e "\033[1m$*\033[0m"
}


#==============================================================================
# getparameter of a ((file, parameter) normal format or (file parameter 1) string format var="value"
#==============================================================================
getparameter()
{
    file=$1
    parameter=$2
    if [ ! -f $file ]
    then
	return 
    fi
    if [ $# = 2 ]
    then
	value=`cat $file | awk -v par=$2 'match($1,par) == 1  {print $0};' | cut -f 2 -d'=' |sed 's/^ *//'`
    else
	value=`cat $file | awk -v par=$2 'match($1,par) == 1  {print $0};' | cut -f 2 -d'=' |sed 's/\"\([^\"]*\)\"/\1/'`
    fi
    eval "$parameter=$value"
}


#-------------------------------------------------------------
# EDC_ENABLE 
#-------------------------------------------------------------

EDC_ENABLE()
{
   EDC=$1
   cat /usr/local/config.txt | sed -e "s/EdcEnable.*/EdcEnable;$EDC/" > /usr/local/config.txt.1
   mv /usr/local/config.txt.1 /usr/local/config.txt
}



#-------------------------------------------------------------
# DEFAULT CONFIG 
# if one argument is given, do not modify user partition
#-------------------------------------------------------------

FUNC_CONFIG_REF()
{  
   if [ "$2" = "1" ]
   then
	NOUSER=1
   else
	NOUSER=0
   fi
  
   # set SIP param to reference
   if [ "$NOUSER" = "0" ]
   then
      cp -f /usr/local/data/hpr0userparam_ref.cfg /user_data/data/hpr0userparam.cfg
    # set wifi_parameters to reference
      cp -f /usr/local/data/wifi_config_ref.txt /user_data/wifi/wifi_config.txt
      cp -f /usr/local/data/wpa_supplicant_ref.conf /user_data/wifi/wpa_supplicant.conf
   fi

   # set hmedia parameters to reference
     cd /usr/local/data
     rm -f ./hmedia.cfg
     ln -s ./hmedia_ref.cfg ./hmedia.cfg

   # set upgrade parameters to reference
     cd /usr/local/startup
     rm -f ./upgrade.cfg
     ln -s ./upgrade_ref.cfg ./upgrade.cfg

   #change specific provisionning CFG file
     cd /usr/local/data
     rm -f ./hprv0param.cfg
     ln -s ./hprv0param_ref.cfg ./hprv0param.cfg

   # set monitor parameters to reference
     cd /usr/local/data
     rm -f ./monitor.cfg
     ln -s ./monitor_ref.cfg ./monitor.cfg

   #set Call Services features to reference
     cd /usr/local/data
     rm -f hpr0call_services.cfg
     ln -s ./hpr0call_services_ref.cfg ./hpr0call_services.cfg

   #EDC Channel is enabled
   EDC_ENABLE 1
   
}

#-------------------------------------------------------------
# CONFIG FOR KPN
# if one argument is given, do not modify user partition
#-------------------------------------------------------------
FUNC_CONFIG_KPN()
{  

    echo ""
    echo "Apply configuration for KPN operator"
    echo ""

   if [ "$2" = "1" ]
   then
	NOUSER=1
   else
	NOUSER=0
   fi
    
   # set default configuration code
     echo "KPN" > /user_data/config_code.txt

   #EDC channel is disabled
   EDC_ENABLE 0

   #set welcome animation
     cd /usr/local/pics/qpe
     rm -f ./splash.gif
     ln -s ./splash-chuck.gif ./splash.gif
    
   #set goodbye animation
     cd /usr/local/pics/qpe
     rm -f ./goodbye.gif
     ln -s ./goodbye-chuck.gif ./goodbye.gif

   #suppress french language
     mkdir /usr/local/i18n/NOTUSED
     mkdir /usr/local/help/NOTUSED
     mv /usr/local/i18n/fr /usr/local/i18n/NOTUSED/
     mv /usr/local/help/fr /usr/local/help/NOTUSED/

   #set default language to dutch
   echo "Set default language to dutch"
   cat /usr/local/etc/default/locale.conf | sed -e "s/Language =.*/Language = nl/" > /usr/local/etc/default/locale.conf.1
   mv /usr/local/etc/default/locale.conf.1 /usr/local/etc/default/locale.conf
   rm -f /user_settings/locale.conf 

   #set Call Services features
     cd /usr/local/data
     rm -f hpr0call_services.cfg
     ln -s ./hpr0call_services_ref_KPN.cfg ./hpr0call_services.cfg

   #Set MMI Call Settings
     cd /usr/local/etc/default
     rm -f CallSettings.conf
     ln -s /usr/local/data/CallSettings_ref_KPN.conf ./CallSettings.conf
     rm -Rf /user_settings/CallSettings.conf

   #Set MMI Registration Settings
     cd /usr/local/etc/default
     rm -f RegistrationSettings.conf
     ln -s /usr/local/data/RegistrationSettings_ref_KPN.conf ./RegistrationSettings.conf
     rm -Rf /user_settings/RegistrationSettings.conf

   #Set MMI SX55 Settings
     cd /usr/local/etc/default
     rm -f sx55.conf
     ln -s /usr/local/data/sx55_ref_KPN.conf ./sx55.conf
     rm -Rf /user_settings/sx55.conf

   #Set MMI Speedtouch Settings
     cd /usr/local/etc/default
     rm -f speedtouch.conf
     ln -s /usr/local/data/speedtouch_ref_KPN.conf ./speedtouch.conf
     rm -Rf /user_settings/speedtouch.conf
   
   #Set MMI SpeeDial Configuration
     cd /usr/local/etc/default
     rm -f SpeedDial.conf
     ln -s /usr/local/data/SpeedDial_ref_KPN.conf ./SpeedDial.conf
   #  rm -Rf /user_settings/SpeedDial.conf

   #Disable CLIR feature 
   if [ -f /usr/local/apps/Settings/calloptions.desktop ]
   then
	  mv /usr/local/apps/Settings/calloptions.desktop /usr/local/apps/Settings/calloptions.desktopMASK
   fi
    
   #Disable Call Forward feature
   if [ -f /usr/local/apps/Settings/callforward.desktop ]
   then
	  mv /usr/local/apps/Settings/callforward.desktop /usr/local/apps/Settings/callforward.desktopMASK
   fi

   #hide date/time menu
   if [ -f /usr/local/apps/Settings/datetime.desktop ] 
   then
	  mv /usr/local/apps/Settings/datetime.desktop /usr/local/apps/Settings/datetime.desktopMASK
   fi

   #change specific hmediamngr CFG file 
     cd /usr/local/data
     rm -f ./hmedia.cfg
     ln -s ./hmedia_ref_KPN.cfg ./hmedia.cfg

   #change specific hprotal CFG file
   if [ "$NOUSER" = "0" ]
   then
        cp -f /usr/local/data/hpr0userparam_ref_KPN.cfg /user_data/data/hpr0userparam.cfg
   fi

   #change specific upgrade CFG file
     cd /usr/local/startup
     rm -f ./upgrade.cfg
     ln -s ./upgrade_ref_KPN.cfg ./upgrade.cfg

   #change specific provisionning CFG file
     cd /usr/local/data
     rm -f ./hprv0param.cfg
     ln -s ./hprv0param_ref_KPN.cfg ./hprv0param.cfg

   #change specific monitor CFG file
     cd /usr/local/data
     rm -f ./monitor.cfg
     ln -s ./monitor_ref_KPN.cfg ./monitor.cfg
}



#--------------------------------
# - CONFIG for field tests
#--------------------------------
FUNC_CONFIG_EFTX()
{

    echo ""
    echo "Apply configuration for External Field Tests"
    echo ""

   if [ "$3" = "1" ]
   then
	NOUSER=1
   else
	NOUSER=0
   fi

   EFT=$1

     echo "$EFT" > /user_data/config_code.txt

   # Set english language by default
   cat /usr/local/etc/default/locale.conf | sed -e "s/Language =.*/Language = en_US/" > /usr/local/etc/default/locale.conf.1
   mv /usr/local/etc/default/locale.conf.1 /usr/local/etc/default/locale.conf
   rm -f /user_settings/locale.conf
    
   # Specific parameter for provisionning 
     cp -f  /usr/local/data/hprv0param_ref_EFT.cfg /usr/local/data/hprv0param.cfg

   #EDC channel is disabled
   EDC_ENABLE 0

   #set welcome animation
     cd /usr/local/pics/qpe
     rm -f ./splash.gif
     ln -s ./splash-obiwan.gif ./splash.gif
    
   #set goodbye animation
     cd /usr/local/pics/qpe
     rm -f ./goodbye.gif
     ln -s ./goodbye-obiwan.gif ./goodbye.gif

   #mask NL language
     mkdir /usr/local/i18n/NOTUSED
     mkdir /usr/local/help/NOTUSED
     mv /usr/local/i18n/nl /usr/local/i18n/NOTUSED/
     mv /usr/local/help/nl /usr/local/help/NOTUSED/

   #specific SIP param for EFTX
   if [ "$NOUSER" = "0" ]
   then
          cp -f /usr/local/data/hpr0userparam_ref_$EFT.cfg /user_data/data/hpr0userparam.cfg
   fi

   #Set MMI Registration Settings
     cd /usr/local/etc/default
     rm -f RegistrationSettings.conf
     ln -s /usr/local/data/RegistrationSettings_ref_EFT.conf ./RegistrationSettings.conf
     rm -Rf /user_settings/RegistrationSettings.conf

   #Set MMI SX55 Settings
     cd /usr/local/etc/default
     rm -f sx55.conf
     ln -s /usr/local/data/sx55_ref.conf ./sx55.conf
     rm -Rf /user_settings/sx55.conf

   #Set MMI Speedtouch Settings
     cd /usr/local/etc/default
     rm -f speedtouch.conf
     ln -s /usr/local/data/speedtouch_ref.conf ./speedtouch.conf
     rm -Rf /user_settings/speedtouch.conf

   #Disable Call Waiting feature
     cp -f  /usr/local/data/CallSettings_ref_KPN.conf /usr/local/etc/default/CallSettings.conf
     rm -Rf /user_settings/CallSettings.conf

   #set Call Services features
     cd /usr/local/data
     rm -f hpr0call_services.cfg
     ln -s ./hpr0call_services_ref_$EFT.cfg ./hpr0call_services.cfg

   #specific hmedia.cfg for both EFT1 and 2
     cd /usr/local/data
     rm -f ./hmedia.cfg
     ln -s ./hmedia_ref_EFT.cfg ./hmedia.cfg

   #specific upgrade for both EFT1 enad EFT2
     cd /usr/local/startup
     rm -f ./upgrade.cfg
     ln -s ./upgrade_ref_EFT.cfg ./upgrade.cfg

   #specific monitor CFG file for EFTx
     cd /usr/local/data
     rm -f ./monitor.cfg
     ln -s ./monitor_ref_EFT.cfg ./monitor.cfg
}



#-------------------------------------------------------------
# CONFIG FOR EN_US
# if one argument is given, do not modify user partition
#-------------------------------------------------------------
FUNC_CONFIG_EN_US()
{
   if [ "$2" = "1" ]
   then
	NOUSER=1
   else
	NOUSER=0
   fi
    
     echo "EN_US" > /user_data/config_code.txt

   cat /usr/local/etc/default/locale.conf | sed -e "s/Language =.*/Language = en_US/" > /usr/local/etc/default/locale.conf.1
   mv /usr/local/etc/default/locale.conf.1 /usr/local/etc/default/locale.conf
   rm -f /user_settings/locale.conf 

  #the .cfg parameters are modified by CONFIG_REF


   #EDC channel is not enabled
   EDC_ENABLE 0
}

#-------------------------------------------------------------
# CONFIG FOR FT
# if one argument is given, do not modify user partition
#-------------------------------------------------------------
FUNC_CONFIG_FT()
{

    echo ""
    echo "Apply configuration for France Telecom operator"
    echo ""

   if [ "$2" = "1" ]
   then
	NOUSER=1
   else
	NOUSER=0
   fi

     echo "FT" > /user_data/config_code.txt
    
   #set language to fr
   cat /usr/local/etc/default/locale.conf | sed -e "s/Language =.*/Language = fr/" > /usr/local/etc/default/locale.conf.1
   mv /usr/local/etc/default/locale.conf.1 /usr/local/etc/default/locale.conf
   rm -f /user_settings/locale.conf

   #EDC channel is disabled
   EDC_ENABLE 0
   
   #set welcome animation
     cd /usr/local/pics/qpe
     rm -f ./splash.gif
     ln -s ./splash-obiwan.gif ./splash.gif
    
   #set goodbye animation
     cd /usr/local/pics/qpe
     rm -f ./goodbye.gif
     ln -s ./goodbye-obiwan.gif ./goodbye.gif

   #specific PROVISIONNING for France Telecom   
     cd /usr/local/data
     rm -f ./hprv0param.cfg
     ln -s ./hprv0param_ref_FT.cfg ./hprv0param.cfg

   #specific SIP param for FT not done if argument is given
   if [ "$NOUSER" = "0" ]
   then
	  cp -f /usr/local/data/hpr0userparam_ref_FT.cfg /user_data/data/hpr0userparam.cfg
   fi

   #specific ugrade for FT
     cd /usr/local/startup
     rm -f ./upgrade.cfg
     ln -s ./upgrade_ref_FT.cfg ./upgrade.cfg

   #specific hmediamngr CFG file for FT
     cd /usr/local/data
     rm -f ./hmedia.cfg
     ln -s ./hmedia_ref_FT.cfg ./hmedia.cfg

   #specific monitor CFG file for FT
     cd /usr/local/data
     rm -f ./monitor.cfg
     ln -s ./monitor_ref_FT.cfg ./monitor.cfg

   #mask NL language
     mkdir /usr/local/i18n/NOTUSED
     mkdir /usr/local/help/NOTUSED
     mv /usr/local/i18n/nl /usr/local/i18n/NOTUSED/
     mv /usr/local/help/nl /usr/local/help/NOTUSED/

   #Set MMI SX55 Settings
     cd /usr/local/etc/default
     rm -f sx55.conf
     ln -s /usr/local/data/sx55_ref.conf ./sx55.conf
     rm -Rf /user_settings/sx55.conf

   #Set MMI Speedtouch Settings
     cd /usr/local/etc/default
     rm -f speedtouch.conf
     ln -s /usr/local/data/speedtouch_ref.conf ./speedtouch.conf
     rm -Rf /user_settings/speedtouch.conf

   #Set MMI SpeeDial Configuration
     cd /usr/local/etc/default
     rm -f SpeedDial.conf
     ln -s /usr/local/data/SpeedDial_ref_FT.conf ./SpeedDial.conf
   #  rm -Rf /user_settings/SpeedDial.conf

   #Set MMI Registration Settings Configuration
     cd /usr/local/etc/default
     rm -f RegistrationSettings.conf
     ln -s /usr/local/data/RegistrationSettings_ref_FT.conf ./RegistrationSettings.conf
     rm -Rf /user_settings/RegistrationSettings.conf

   #set Call Services features
     cd /usr/local/data
     rm -f hpr0call_services.cfg
     ln -s ./hpr0call_services_ref_FT.cfg ./hpr0call_services.cfg

   #specific SIP param for FT not done if argument is given
   if [ "$NOUSER" = "0" ]
   then
	  cp -f /usr/local/data/hpr0userparam_ref_FT.cfg /user_data/data/hpr0userparam.cfg
   fi

   #Disable Call Forward feature
   if [ -f /usr/local/apps/Settings/callforward.desktop ]
   then
	  mv /usr/local/apps/Settings/callforward.desktop /usr/local/apps/Settings/callforward.desktopMASK
   fi

   #Disable CLIR feature 
   if [ -f /usr/local/apps/Settings/calloptions.desktop ]
   then
	  mv /usr/local/apps/Settings/calloptions.desktop /usr/local/apps/Settings/calloptions.desktopMASK
   fi
}


#================================================
CHECK_FILE()
{
    FILE1=$1
    FILE2=$2
    if [ ! -f $FILE1 ]
    then
	echo "$FILE1 does not exist"
    elif [ ! -f $FILE2 ]
    then
	echo "$FILE2 does not exist"
    elif
	[ "`diff $FILE1 $FILE2`" = "" ]
    then
	echo "OK"
    else
	echo "NOT OK"
    fi
}

#================================================
# FUNC_CHECK_CONFIG : checks the current configuration
#================================================

FUNC_CHECK_CONFIG()
{
    CONFIG_CODE=`cat /user_data/config_code.txt`
    OPER=""
    case $CONFIG_CODE in
      FT)
	 OPER="FT"
	 #set welcome animation
	 echo "welcome animation: " 
	 CHECK_FILE /usr/local/pics/qpe/splash-obiwan.gif /usr/local/pics/qpe/splash.gif
	 #set goodbye animation
	 echo "goodbye animation:" 
	 CHECK_FILE /usr/local/pics/qpe/goodbye-obiwan.gif /usr/local/pics/qpe/goodbye.gif	 
	 #set call settings
	 echo "callsettings"
	 CHECK_FILE /usr/local/data/CallSettings_ref.conf /usr/local/etc/default/CallSettings.conf
	 #set speeddial
	 echo "speeddial"
	 CHECK_FILE /usr/local/data/SpeedDial_ref_FT.conf /usr/local/etc/default/SpeedDial.conf
	 #set registrations 
	 echo "registrations:"
	 CHECK_FILE /usr/local/data/RegistrationSettings_ref_FT.conf /usr/local/etc/default/RegistrationSettings.conf
	 ;;

       KPN)
	 OPER="KPN"
	 #set welcome animation
	 echo "welcome animation: " 
	 CHECK_FILE /usr/local/pics/qpe/splash-chuck.gif /usr/local/pics/qpe/splash.gif
	 #set goodbye animation
	 echo "goodbye animation:" 
	 CHECK_FILE /usr/local/pics/qpe/goodbye-chuck.gif /usr/local/pics/qpe/goodbye.gif
	 #set call settings
	 echo "callsettings"
	 CHECK_FILE /usr/local/data/CallSettings_ref_KPN.conf /usr/local/etc/default/CallSettings.conf
	 #set speeddial
	 echo "speeddial"
	 CHECK_FILE /usr/local/data/SpeedDial_ref.conf /usr/local/etc/default/SpeedDial.conf
	 #set registrations 
	 echo "registrations:"
	 CHECK_FILE /usr/local/data/RegistrationSettings_ref.conf /usr/local/etc/default/RegistrationSettings.conf
	 ;;
	EN_US)
	 OPER=""
	 #set welcome animation
	 echo "welcome animation: " 
	 CHECK_FILE /usr/local/pics/qpe/splash-chuck.gif /usr/local/pics/qpe/splash.gif
	 #set goodbye animation
	 echo "goodbye animation:" 
	 CHECK_FILE /usr/local/pics/qpe/goodbye-chuck.gif /usr/local/pics/qpe/goodbye.gif
	 #set call settings
	 echo "callsettings"
	 CHECK_FILE /usr/local/data/CallSettings_ref.conf /usr/local/etc/default/CallSettings.conf
	 #set speeddial
	 echo "speeddial"
	 CHECK_FILE /usr/local/data/SpeedDial_ref.conf /usr/local/etc/default/SpeedDial.conf
	 #set registrations 
	 echo "registrations:"
	 CHECK_FILE /usr/local/data/RegistrationSettings_ref.conf /usr/local/etc/default/RegistrationSettings.conf
	 ;;
	*)
	 OPER=""
	 ;;
    esac 
    #langage must be fr
    becho "langage :" 
    getparameter /usr/local/etc/default/locale.conf Language
    becho $Language
    #echo langage available
    becho "langages:" `ls  /usr/local/i18n`

    #different files
    becho "CONFIGURATION FILES"
    for filecfg in  "/usr/local/data/hpr0userparam" \
		    "/usr/local/data/hprv0param" \
		    "/usr/local/data/hmedia"\
		    "/usr/local/data/monitor" \
		    "/usr/local/startup/upgrade"
    do
	echo "$filecfg is:"
	if [ "$OPER" = "" ]
	then
	    CHECK_FILE ${filecfg}_ref.cfg ${filecfg}.cfg 
	else
	    CHECK_FILE ${filecfg}_ref_$OPER.cfg ${filecfg}.cfg 
	fi
    done
    #menus available
    becho "available :" 
    for file in $(ls /usr/local/apps/Settings/*.desktop)
    do 
	echo $file | sed 's%/usr/local/apps/Settings/%%'
    done
    becho "not available"
      ls /usr/local/apps/Settings/*.desktopMASK
    if [ $? = 0 ] 
    then
	for file in $(ls /usr/local/apps/Settings/*.desktopMASK)
	do
	    echo $file | sed 's%/usr/local/apps/Settings/%%'
	done
    fi
    becho "not available" 
      ls /usr/local/apps/Applications/*.desktopMASK
    if [ $? = 0 ] 
    then
	for file in $(ls /usr/local/apps/Applications/*.desktopMASK)
	do
	    echo $file | sed 's%/usr/local/apps/Settings/%%'
	done
    fi
    becho "Call Waiting feature:"
    getparameter /usr/local/etc/default/CallSettings.conf CallWaitingAvailable
    echo $CallWaitingAvailable
    becho "CLIR feature"
    getparameter /usr/local/etc/default/CallSettings.conf CLIRAvailable
    echo $CLIRAvailable
	 
}




#================================================
# RESET PARAMETER
#================================================
#-------------------------------------------------------------
# - RESET MMI PARAMETER - Called by MMI menu (not in MAT mode)
#-------------------------------------------------------------
FUNC_RESET_MMI_PARAM()
{
    echo ""
    echo "Reset MMI parameters"
    echo ""

    # delete call log
      rm -f /user_data/home/Applications/dialer/CallList
    # delete appearance/power management/ring profiles/speed dial
      rm -rf /user_settings/qpe.conf
      rm -rf /user_settings/SpeedDial.conf
      rm -rf /user_settings/PhoneProfile.conf
    # reset language
      rm -rf /user_settings/locale.conf
    # delete Tv settings
      rm -rf /user_settings/TvSettings.conf
    # clir
      rm -rf /user_settings/Phone.conf
    # online volume
      rm -rf /user_settings/CallSettings.conf
    # keypad sound
      rm -rf /user_settings/Sound.conf
}


#-------------------------------------------------------------
# - CONFIG_MMI_REF set default parameters for MMI
#-------------------------------------------------------------
FUNC_CONFIG_MMI_REF()
{

    echo ""
    echo "Set default parameters for MMI"
    echo ""

    ##restore all MMI_SETTINGS
      cd /usr/local/etc/default
      rm -Rf ./CallSettings.conf
      ln -s /usr/local/data/CallSettings_ref.conf ./CallSettings.conf
      rm -Rf ./Security.conf
      ln -s /usr/local/data/Security.conf ./Security.conf
      rm -Rf ./Contacts.conf
      ln -s /usr/local/data/Contacts.conf ./Contacts.conf
      rm -Rf ./SpeedDial.conf
      ln -s /usr/local/data/SpeedDial_ref.conf ./SpeedDial.conf
      rm -Rf ./EmergencyNumber.conf
      ln -s /usr/local/data/EmergencyNumber.conf ./EmergencyNumber.conf
      rm -Rf ./TvSettings.conf
      ln -s /usr/local/data/TvSettings.conf ./TvSettings.conf
      rm -Rf ./FontMap.conf
      ln -s /usr/local/data/FontMap.conf ./FontMap.conf
      rm -Rf ./customVido.conf
      ln -s /usr/local/data/customVido.conf ./customVido.conf
      rm -Rf ./IconSizes.conf
      ln -s /usr/local/data/IconSizes.conf ./IconSizes.conf
      rm -Rf ./locale.conf
      ln -s /usr/local/data/locale.conf ./locale.conf
      rm -Rf ./Phone.conf
      ln -s /usr/local/data/Phone.conf ./Phone.conf
      rm -Rf ./presstick.conf
      ln -s /usr/local/data/presstick.conf ./presstick.conf
      rm -Rf ./PhoneProfile.conf
      ln -s /usr/local/data/PhoneProfile.conf ./PhoneProfile.conf
      rm -Rf ./qpe.conf
      ln -s /usr/local/data/qpe.conf ./qpe.conf
      rm -Rf ./RegistrationSettings.conf
      ln -s /usr/local/data/RegistrationSettings_ref.conf ./RegistrationSettings.conf
      rm -Rf ./speedtouch.conf
      ln -s /usr/local/data/speedtouch_ref.conf ./speedtouch.conf
      rm -Rf ./sx55.conf
      ln -s /usr/local/data/sx55_ref.conf ./sx55.conf
      rm -Rf ./AutoDemoMode.conf
      ln -s /usr/local/data/AutoDemoMode_ref.conf ./AutoDemoMode.conf

    #set default welcome animation
      cd /usr/local/pics/qpe
      rm -f ./splash.gif
      ln -s ./splash-obiwan.gif ./splash.gif
    
    #set default goodbye animation
      cd /usr/local/pics/qpe
      rm -f ./goodbye.gif
      ln -s ./goodbye-obiwan.gif ./goodbye.gif

    ##restore all desktop files
    #Enable date/time menu
    if [ -f /usr/local/apps/Settings/datetime.desktopMASK ]
    then
          mv /usr/local/apps/Settings/datetime.desktopMASK /usr/local/apps/Settings/datetime.desktop
    fi
    #Enable Call Options menu
    if [ -f /usr/local/apps/Settings/calloptions.desktopMASK ]
    then
          mv /usr/local/apps/Settings/calloptions.desktopMASK /usr/local/apps/Settings/calloptions.desktop
    fi
    #Enable Call Forward menu
    if [ -f /usr/local/apps/Settings/callforward.desktopMASK ]
    then
          mv /usr/local/apps/Settings/callforward.desktopMASK /usr/local/apps/Settings/callforward.desktop
    fi

    # Restore default charge beep
    if [ -f /usr/local/sounds/charge_ref.wav ]
    then
          cd /usr/local/sounds
          rm -f charge.wav
          ln -s ./charge_ref.wav ./charge.wav
    fi

    #Restore All Languages 
    if [ -d /usr/local/i18n/NOTUSED ];then
        if [ -d /usr/local/i18n/NOTUSED/nl ];then
            echo "Restore NL language files"
              mv /usr/local/i18n/NOTUSED/nl /usr/local/i18n
        fi
        if [ -d /usr/local/i18n/NOTUSED/fr ];then
            echo "Restore FR language files"
              mv /usr/local/i18n/NOTUSED/fr /usr/local/i18n
        fi
        if [ -d /usr/local/i18n/NOTUSED/en_US ];then
            echo "Restore US language files"
              mv /usr/local/i18n/NOTUSED/en_US /usr/local/i18n
        fi
          rm -Rf /usr/local/i18n/NOTUSED
    fi

    if [ -d /usr/local/help/NOTUSED ];then
        if [ -d /usr/local/help/NOTUSED/nl ];then
            echo "Restore NL help files"
              mv /usr/local/help/NOTUSED/nl /usr/local/help
        fi
        if [ -d /usr/local/help/NOTUSED/fr ];then
            echo "Restore FR help files"
              mv /usr/local/help/NOTUSED/fr /usr/local/help
        fi
        if [ -d /usr/local/help/NOTUSED/en_US ];then
            echo "Restore US help files"
              mv /usr/local/help/NOTUSED/en_US /usr/local/help
        fi
          rm -Rf /usr/local/help/NOTUSED
    fi

}

#-------------------------------------------------------------
# - SAV RESET MMI PARAMETER 
#-------------------------------------------------------------
FUNC_SAV_RESET_MMI_PARAM()
{
    echo ""
    echo "SAV Reset MMI parameters"
    echo ""

    ## set default parameters for MMI
    FUNC_CONFIG_MMI_REF

    ## delete call log
      rm -f /user_data/home/Applications/dialer/CallList

    ##remove all MMISEttings from /user_settings
    for file in $(ls /usr/local/etc/default/*)
    do 
        if [ -f /user_settings/`basename $file` ]
            then
                  rm /user_settings/`basename $file`
        fi
    done
}


#--------------------------------
# - RESET_ALL_PARAM_WPHBK
#--------------------------------
FUNC_RESET_ALL_PARAM_WPHBK()
{

    echo ""
    echo "Reset all MMI parameters without phonebook"
    echo ""

    #reset prod counters
      echo "0" > /user_data/prod/counters.txt
      echo "0" >> /user_data/prod/counters.txt
      echo "0" >> /user_data/prod/counters.txt
    
    #reset MMI_PARAM
    FUNC_SAV_RESET_MMI_PARAM;
   
}


#--------------------------------
# - RESET PARAMETER
#--------------------------------
FUNC_RESET_ALL_PARAM()
{
    echo ""
    echo "Reset ALL parameters"
    echo ""

    # delete config_code
    rm -f /user_data/config_code.txt

    # delete phonebook
    rm -Rf /user_data/home/Applications/addressbook/contactimages
    rm /user_data/home/Applications/addressbook/addressbook.xml

    # delete all "photo in idle & photocall"
    rm -Rf /user_data/home/Documents/*:*.jpg
    rm -Rf /user_data/home/Documents/image
   
    # % available for user
    rm -Rf /user_settings/sysinfo.conf
    
    #restore default parameters sip wifi ...
    FUNC_CONFIG_REF

    FUNC_RESET_ALL_PARAM_WPHBK;
}


#--------------------------------
# - RESET PARAMETER
#--------------------------------
FUNC_SAV_RESET_ALL_PARAM()
{
   # gets config_code
   if [ -f /user_data/config_code.txt ]
   then
	CONFIG_CODE=`cat /user_data/config_code.txt`
   else
	CONFIG_CODE=""
   fi
   #resets all params
   FUNC_RESET_ALL_PARAM
   #re apply config
   case $CONFIG_CODE in
	KPN)
	    echo "Re apply KPN configuration"
	    FUNC_CONFIG_KPN
	;;

	EN_US)
	    echo "Re apply EN_US configuration"
	    FUNC_CONFIG_EN_US
	;;

	FT)
	    echo "Re apply FT configuration"
	    FUNC_CONFIG_FT
	;;

	EFT1)
	    echo "Re apply EFT1 configuration"
	    FUNC_CONFIG_EFTX EFT1
	;;   

	EFT2)
	    echo "Re apply EFT2 configuration"
	    FUNC_CONFIG_EFTX EFT2
	;;   

esac	
}





#--------------------------------
# - get network info as wifiparameter.sh
#--------------------------------
FUNC_GET_NETWORK_INFO()
{
  CURRENT_ESSID="`iwconfig eth0 | grep ESSID | cut -d'"' -f2`"
  #Proxy, current SSID, Alias, IP adress, SSID
  echo "PROXY:`cat /usr/local/data/hpr0userparam.cfg | awk '$1 ~ /^SIP_REGISTRAR_SERVER_ADDRESS/ {print $1};' |cut -f 2 -d'='`"
  echo "SSID:$CURRENT_ESSID;"
  echo "ALIAS:`cat /usr/local/data/hpr0userparam.cfg | awk '$1 ~ /^SIP_USER_NAME/ {print $1};'|cut -f 2 -d'=';`"
  echo "IP:`ifconfig eth0 | awk '$1 ~ /^inet$/ {print $2}' | cut -d':' -f2`;"
  echo "SCAN:$CURRENT_ESSID;`iwlist eth0 scan | grep ESSID | awk '{print $1}' | cut -d'"' -f2 | sort | tr '\n' ';'`"
}

#--------------------------------
# - set network info as wifiparameter.sh
#--------------------------------
FUNC_SET_NETWORK_INFO()
{

  ALIAS=$1
  PROXY=$2
  SSID=$3
  PASSWD=$4

#set ALIAS
  mv  /user_data/data/hpr0userparam.cfg /user_data/data/hpr0userparam.cfg.old
  cat /user_data/data/hpr0userparam.cfg.old | sed -e "s/SIP_USER_NAME.*/SIP_USER_NAME=$ALIAS/" > /user_data/data/hpr0userparam.cfg
  rm  /user_data/data/hpr0userparam.cfg.old


#set PROXY
  mv  /user_data/data/hpr0userparam.cfg /user_data/data/hpr0userparam.cfg.old
  cat /user_data/data/hpr0userparam.cfg.old | sed -e "s/SIP_REGISTRAR_SERVER_ADDRESS.*/SIP_REGISTRAR_SERVER_ADDRESS=$PROXY/" > /user_data/data/hpr0userparam.cfg
  rm  /user_data/data/hpr0userparam.cfg.old

#set PASSWD
  mv  /user_data/data/hpr0userparam.cfg /user_data/data/hpr0userparam.cfg.old
  cat /user_data/data/hpr0userparam.cfg.old | sed -e "s/PASSWORD.*/PASSWORD=$PASSWD/" > /user_data/data/hpr0userparam.cfg
  rm  /user_data/data/hpr0userparam.cfg.old

  # TEMP FIXME
  if [ -f /user_data/wifi/wifi_config.txt ]
  then
    cp  /user_data/wifi/wifi_config.txt /user_data/wifi/wifi_config.txt.sav
    cat /user_data/wifi/wifi_config.txt.sav | sed -e "s/ENCRYPTION_TYPE.*/ENCRYPTION_TYPE=4/" > /user_data/wifi/wifi_config.txt
    rm  /user_data/wifi/wifi_config.txt.sav
  fi
   

  cat /user_data/wifi/wpa_supplicant.conf | sed -e "s/ssid.*/ssid=\"\"/" > /user_data/wifi/wpa_supplicant.conf.sav
  rm  /user_data/wifi/wpa_supplicant.conf
  cat /user_data/wifi/wpa_supplicant.conf.sav | sed -e "s/psk.*/psk=/" > /user_data/wifi/wpa_supplicant.conf 
  rm  /user_data/wifi/wpa_supplicant.conf.sav
  mv  /user_data/wifi/wpa_supplicant.conf /user_data/wifi/wpa_supplicant.conf.sav
  cat /user_data/wifi/wpa_supplicant.conf.sav | sed -e "s/scan_ssid.*/scan_ssid=1/" > /user_data/wifi/wpa_supplicant.conf
  rm  /user_data/wifi/wpa_supplicant.conf.sav

  # set the essid now -> no need to reboot
  iwconfig eth0 essid "$SSID"

}


#================================================
# [SCENARI]
# CONFIG_XX -> nop more reset is done
#================================================
case $1 in
   CONFIG_KPN)
      FUNC_CONFIG_REF $*
      FUNC_CONFIG_MMI_REF $*
      FUNC_CONFIG_KPN $*
   ;;

   CONFIG_EN_US)
      FUNC_CONFIG_REF $*
      FUNC_CONFIG_MMI_REF $*
      FUNC_CONFIG_EN_US $*
   ;;

   CONFIG_FT)
      FUNC_CONFIG_REF $*
      FUNC_CONFIG_MMI_REF $*
      FUNC_CONFIG_FT $*
   ;;

   CONFIG_EFT1)
      FUNC_CONFIG_REF $*
      FUNC_CONFIG_MMI_REF $*
      FUNC_CONFIG_EFTX EFT1 $*
   ;;

   CONFIG_EFT2)
      FUNC_CONFIG_REF $*
      FUNC_CONFIG_MMI_REF $*
      FUNC_CONFIG_EFTX EFT2 $*
   ;;

#checks the config
   CHECK_CONFIG)
      FUNC_CHECK_CONFIG
   ;;
#checks all
    CHECK_ALL)
	echo "CHECK KPN CONFIG"
	$0 CONFIG_KPN
	$0 CHECK_CONFIG
	$0 SAV_RESET_ALL_PARAM
	echo "CHECK FT CONFIG"
	$0 CONFIG_FT
	$0 CHECK_CONFIG
	$0 SAV_RESET_ALL_PARAM
	echo "CHECK EN_US CONFIG"
	$0 CONFIG_EN_US
	$0 CHECK_CONFIG
	$0 SAV_RESET_ALL_PARAM
	echo "CHECK NETWORK INFO"
	$0 GET_NETWORK_INFO
   ;;
##get alias   
   GET_NETWORK_INFO)
     FUNC_GET_NETWORK_INFO
   ;;

##set alias 
   SET_NETWORK_INFO)
     if [ $# = 5 ] ; then
       FUNC_SET_NETWORK_INFO $2 $3 $4 $5
     else
	echo "ALIAS:"
	read ALIAS
	echo "PROXY:"
	read PROXY
	echo "SSID:"
	read SSID
	echo "PASSWD:[enter = empty]"
	read PASSWD
	FUNC_SET_NETWORK_INFO $ALIAS $PROXY $SSID $PASSWD
      fi
   ;;

 #xxxxxxxxxxxxxxxxxxxxxxxx
 #be careful this scripts were not in previous version

   FUNC_RESET_ALL_PARAM_WPHBK)
      FUNC_RESET_ALL_PARAM_WPHBK;
   ;;

   FUNC_RESET_ALL_PARAM)
      FUNC_RESET_ALL_PARAM;
   ;;

   FUNC_RESET_MMI_PARAM)
      FUNC_RESET_MMI_PARAM;
   ;;
    #reset param and get again the precedent config
    SAV_RESET_ALL_PARAM)
      FUNC_SAV_RESET_ALL_PARAM;
   ;;
    *)
     echo "=================================="
     echo " Scenari unknown " 
     echo "=================================="
    ;;
esac
