#!/bin/bash

# uncomment the line below for debuging the script:
# set -x

kill_process ()
{
	echo -n "Waiting end of process $1"
	killall $1 2>/dev/null 1>&2
	while (ps | grep -i $1 2>/dev/null 1>&2)
	do
	  echo -n "."
	  sleep 1
	done
	echo ""
}

TINDETECT="TRUE"

#if second argument = noTINdetect, the application should start even if BBON is connected to ground
if [ $# -eq 2 ] && [ $2 = "noTINdetect" ]; then
   TINDETECT="FALSE"
fi

case "$1" in

    start)

    # Start WPA supplicant
    cd /user_data/wifi
    ./run

    export PATH=$PATH:/user_data/prod

    # hardware management: read from HHWSTRAP
    TARGET_TYPE=`cat /proc/hhwstrap | cut -d ' ' -f 1 -`


# BEGIN OF DMAB RESERVATION FOR VE 
# MUST BE EXECUTE ONLY ONCE AT STARTUP OF THE PRODUCT

#only run the following code if /proc/vbufpool exists
    if [ -e /proc/vbufpool ]
    then
    #check is we have already setup /proc/vbufpool, we only want
    #to set this up once. Note the 'sed' lines prevent mismatches on the
    # 'Allocation Histogram' part of the /proc/vbufpool output which would
    #confuse things
	vbufpool_init=`cat /proc/vbufpool|sed -n -e '/ cached/p' -e '/Histogram/q'|grep 202752`
	if [ "$vbufpool_init" = '' ]
	then
        # This adds 14 dmab buffers of 202752 bytes we will then 
        # use this pool.
	    echo add:14x202752-nc > /proc/vbufpool
	fi	

	vbufpool_init=`cat /proc/vbufpool|sed -n -e '/ cached/p' -e '/Histogram/q'|grep 614400`
	if [ "$vbufpool_init" = '' ]
	then

        # This adds 1 dmab buffers of 614400 bytes we will then 
        # use this pool.
	    echo add:1x614400-nc > /proc/vbufpool
	fi	
    fi  

# END OF DMAB RESERVATION FOR VE 


    # Application not started when BB_ON v=connected to ground
    if [ ! $TARGET_TYPE = "ads" ] && [ $TINDETECT = "TRUE" ]; then
       #MTX patch to detect autoboot or not
       AUTOBOOT=`HC1_ats.sh START_MODE`
#       AUTOBOOT=1
       if [ -e /tmp/autoboot ] || [ $AUTOBOOT -eq 0 ]; then
          # when using the autoboot mode, use kpp with debug traces for MTX
          rmmod doze kpp
          insmod /usr/local/drivers/debug_kpp.o
          insmod /usr/local/drivers/doze.o
          exit 0;
       fi
    fi


	# default network interface: eth0. On ADS it could be set to eth1 if ethernet and wifi are used together
	INTERFACE="eth0"

	# generate hostname based on the HW mac address i.e: chuck_88DFDA or chuck_601f60
	HOSTNAME=OBIWAN_`cat /user_data/data/macaddress.cfg |cut -b 7-12`
	hostname $HOSTNAME

	cd /mnt/ramfs1

	# copy files
	cp /usr/local/config.txt .
	cp /usr/local/bin/qpe .

	echo $INTERFACE > netsync.cfg
	echo $HOSTNAME >> netsync.cfg
	# set the default DHCP lease time
        echo 86400 >> netsync.cfg

	cp /usr/local/startup/netsyncd .
	cp /usr/local/startup/upgraded .

	./netsyncd &
	./upgraded -v 1 -t -a -w &

	sync  # lets synchronise the filesystem ...

	################################
	# launch MMI QTOPIA application
	################################
	export QPEDIR=/usr/local
	export QTDIR=$QPEDIR
	export LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
	export QWS_SIZE="176x220"
	export QWS_DISPLAY="Transformed:Rot0:0"
	export QWS_KEYBOARD="TTY:/dev/buttons"
	export HOME=/home
	export KDEHOME=$QTDIR
	export PATH=$QTDIR/bin:$PATH
	#export LD_DEBUG=files

	CMD="./qpe -conf config.txt"
	echo $CMD
	$CMD &

	# capture mapping of libs in memory
	touch /user_data/maps.txt
	sleep 20 && (mv /user_data/maps.txt /user_data/maps_old.txt; cat /proc/*/maps | sort | uniq > /user_data/maps.txt) &

	# Hack for ADS only: get the REGISTRATION DONE using EDC (since no wifimgr) !
	[ "$TARGET_TYPE" = "ads" ] && sleep 40 && ( sleep 1; echo "hsnd;1;4"; sleep 1) | /root/bin/telnet 127.0.0.1 12000 &

	;;

    stop)
	# kill process
	killall qpe
	killall quicklauncher
	killall subscription
	killall netsyncd
	killall upgraded


	#clean ipc resources
	echo "Remove shared memory"
	ipcs -m | grep -v 0x414e4547 | awk '$3 == "root" {print "ipcrm shm " $2}' | sh 2>/dev/null 1>&2
	echo "Remove semaphore identifier"
	ipcs -s | grep -v 0x414e4547 | awk '$3 == "root" {print "ipcrm sem " $2}' | sh 2>/dev/null 1>&2
	echo "Remove message queue"
	ipcs -q | grep -v 0x414e4547 | awk '$3 == "root" {print "ipcrm msg " $2}' | sh 2>/dev/null 1>&2
	
	# and fifos
	rm -rf /mnt/ramfs1/fifo* 2>/dev/null 1>&2
	;;

    reload|restart)
	$0 stop
	sleep 1
	$0 start
	;;

    *)
	echo "Usage: $0 (start|stop|reload)"
	exit 1
	;;

esac

exit 0
